#!/usr/bin/env python
#example

# python ReadSCFileNominal.py NominalGain/ physics_20061108_220357.4

from I3Tray import *
from os.path import expandvars

indir = "/disk3/data/RealData/2007/level0/0801/"
runname   = "PFFilt_PhysicsTrig_PhysicsFiltering_Run00108984_Level0"
outdir = "/home/mase/work/I3/SIMULATION/V02EHE/build/data/eheoptimized/"

if len(sys.argv) > 1:
	indir = sys.argv[1]
	
if len(sys.argv) > 2:
	runname = sys.argv[2]
		
inphysfile = indir + runname + "_Part00000000.i3.gz"
ingcsfile = indir + runname + "_GCD.i3.gz"
outfile = outdir + runname + ".root"
outcanvas1file = outdir + runname + "-canvas1.gif"
outcanvas2file = outdir + runname + "-canvas2.gif"

print ingcsfile
print inphysfile
#outfile 

load("libicetray")
load("libdataclasses")
load("libphys-services")
load("libdataio")
load("libpfclasses")
load("libDOMcalibrator")
#load("libtriggerUtil-C++")
#our module
load("libportia")
load("libophelia")
load("librealtree-module")
#load("../../../Sim-V01-09-04-EHE/Linux-i386/lib/librealtree-module")

tray = I3Tray()

tray.AddService("I3ReaderServiceFactory","reader")(
    ("FilenameList", [ingcsfile, inphysfile]),
    ("SkipUnregistered", True)
    )

tray.AddModule("I3Muxer", "multiplex")

tray.AddModule("I3DOMcalibrator","DOMcalib")(
	("CorrectPedestalDroop", False),
	("CalibrationMode", 1),
	)

tray.AddModule("I3Portia","pulse")(
  ("DataReadoutName",             "InIceRawData"),
  ("ATWDPulseSeriesName",         "ATWDPulseSeries"),
  ("ATWDPortiaPulseName",         "ATWDPortiaPulse"),
  ("ATWDWaveformName",            "CalibratedATWD"),
#
  ("ATWDBaseLineOption",          "eheoptimized"),
  ("FADCBaseLineOption",          "eheoptimized"),
  #("ATWDBaseLineOption",          "iteration"),
  #("FADCBaseLineOption",          "iteration"),
  #("ATWDBaseLineOption",          "zerobaseline"),
  #("FADCBaseLineOption",          "zerobaseline"),
  #("ATWDBaseLineOption",          "first"),
  #("FADCBaseLineOption",          "first"),
#
  ("ATWDThresholdCharge",         0.0*I3Units.C),
  ("ATWDLEThresholdAmplitude",    0.5*I3Units.mV),

  ("UseFADC", True),
  ("FADCPulseSeriesName",         "FADCPulseSeries"),
  ("FADCPortiaPulseName",         "FADCPortiaPulse"),
  ("FADCWaveformName",            "CalibratedFADC"),
  ("FADCThresholdCharge",         0.0*I3Units.C),
  ("FADCLEThresholdAmplitude",    0.5*I3Units.mV),
  ("MakeBestPulseSeries",         False),
  ("BestPortiaPulseName",         "BestPortiaPulse"),
  #("PMTGain",                     1.0e7)
  #("PMTGain",                      5.0e6)
)

tray.AddModule("I3EHEFirstGuess", "reco")(
  ("MinimumNumberPulseDom",  8),
  ("OutputFirstguessName",   "OpheliaFirstGuess"),
  ("InputPulseName1",        "ATWDPortiaPulse"),
  ("InputPulseName2",        "FADCPortiaPulse"),
  ("InputLaunchName",        "InIceRawData"),
  ("ChargeOption",           0),
  ("LCOption",               True)
)

tray.AddModule("I3RealTreeModule","real")(
  ("outTreeName",            "RealTree"),
  ("outFileName",            outfile),  
  ("inDOMLaunchName",        "InIceRawData"),
  ("UseIceTopPulse",         True),
  ("inTopDOMLaunchName",     "IceTopRawData"),
  ("doPulseTree",            True),
  ("inAtwdPortiaName",       "ATWDPortiaPulse"),
  ("inFadcPortiaName",       "FADCPortiaPulse"),
  ("doWaveformDraw",         True),
  ("DrawOption",             2),
  ("inAtwdWaveformToDraw",   "CalibratedATWD"),
  ("inFadcWaveformToDraw",   "CalibratedFADC"),
  ("outputCanvas1Name",      outcanvas1file),
  ("outputCanvas2Name",      outcanvas2file),   
  ("doFirstguessTree",       True),
  ("inFirstguessName",       "OpheliaFirstGuess")
)

tray.AddModule("TrashCan", "bye")

tray.Execute()
tray.Finish()
